==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/pt_BR.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "A tag de sistema %1$s foi adicionado pelo sistema",
    "Added system tag {systemtag}" : "Adicionada a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Adicionada a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s adicionou a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} adicionou a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "A tag de sistema %1$s foi removida pelo sistema",
    "Removed system tag {systemtag}" : "Etiqueta de sistema excluída {systemtag}",
    "Removed system tag %1$s" : "Excluída a etiqueta da sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Você criou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Você criou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s criou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} criou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Você excluiu a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Você excluiu a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Você atualizou a etiqueta de sistema %2$s para %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Você atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atualizou a etiqueta de sistema %3$s para %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "A tag de sistema %2$s foi adicionado %1$s pelo sistema",
    "System tag {systemtag} was added to {file} by the system" : "A tag do sistema {systemtag} foi adicionada ao {file} pelo sistema",
    "You added system tag %2$s to %1$s" : "Você adicionou a etiqueta de sistema %2$s para %1$s",
    "You added system tag {systemtag} to {file}" : "Você adicionou a etiqueta de sistema {systemtag} para {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s adicionou a etiqueta de sistema %3$s para %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} adicionou a etiqueta de sistema {systemtag} para {file}",
    "System tag %2$s was removed from %1$s by the system" : "A tag de sistema %2$s foi removida de %1$s pelo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "A tag de sistema {systemtag} foi removida de {file} pelo sistema",
    "You removed system tag %2$s from %1$s" : "Você excluiu a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Você excluiu a etiqueta de sistema {systemtag} de {file} ",
    "%1$s removed system tag %3$s from %2$s" : "%1$s excluiu a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} excluiu a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrito)",
    "%s (invisible)" : "%s (invisível)",
    "<strong>System tags</strong> for a file have been modified" : "As <strong>etiquetas de sistema</strong> para um arquivo foram modificadas",
    "Files" : "Arquivos",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos os %s marcados …",
    "tagged %s" : "marcado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas. Ótimo para equipes. \n\t(Se você for um provedor com instalação multilocatária, é aconselhável desativar este aplicativo, pois as etiquetas são compartilhadas.)",
    "Public" : "Público",
    "Restricted" : "Restrito",
    "Invisible" : "Invisível",
    "Created tag" : "Etiqueta criada",
    "Failed to create tag" : "Falha ao criar etiqueta",
    "Updated tag" : "Etiqueta atualizada",
    "Failed to update tag" : "Falha ao atualizar a etiqueta",
    "Deleted tag" : "Etiqueta excluída",
    "Failed to delete tag" : "Falha ao excluir etiqueta",
    "Create or edit tags" : "Criar ou editar etiquetas",
    "Search for a tag to edit" : "Procure uma etiqueta para editar",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "No tags to select" : "Nenhuma etiqueta para selecionar",
    "Tag name" : "Nome da etiqueta",
    "Tag level" : "Nível de etiqueta",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Delete" : "Excluir",
    "Reset" : "Redefinir",
    "Loading …" : "Carregando …",
    "{displayName} (hidden)" : "{displayName} (escondida)",
    "{displayName} (restricted)" : "{displayName} (restrita)",
    "Failed to apply tags changes" : "Falha ao aplicar alterações de etiquetas",
    "File tags modification canceled" : "Modificação de etiquetas de arquivo cancelada",
    "Manage tags" : "Gerenciar etiquetas",
    "Applying tags changes…" : "Aplicando mudanças de etiquetas…",
    "Search or create tag" : "Pesquisar ou criar etiqueta",
    "Change tag color" : "Alterar cor da tag",
    "Create new tag" : "Crie uma etiqueta nova",
    "Select or create tags to apply to all selected files" : "Selecione ou crie etiquetas para aplicar a todos os arquivos selecionados",
    "Cancel" : "Cancelar",
    "Apply changes" : "Aplicar alterações",
    "Failed to load tags" : "Erro ao carregar rótulos",
    "Failed to load selected tags" : "Falha ao carregar as etiquetas selecionadas",
    "Failed to select tag" : "Falha ao selecionar etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "O administrador do sistema desativou a criação de tags. Você só pode usar as que já existem.",
    "Loading collaborative tags …" : "Carregando etiquetas,s colaborativas…",
    "Search or create collaborative tags" : "Pesquise ou crie etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "Nenhuma etiqueta para selecionar, digite para criar uma nova etiqueta",
    "Unable to update setting" : "Não foi possível atualizar a configuração",
    "System tag creation is now restricted to administrators" : "A criação de tags do sistema agora está restrita aos administradores",
    "System tag creation is now allowed for everybody" : "A criação de tags do sistema agora está liberada para todos",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
    "Assigned collaborative tags" : "Etiquetas colaborativas atribuídas",
    "Open in Files" : "Abrir em arquivos",
    "List of tags and their associated files and folders." : "Lista de etiquetas e seus arquivos e pastas associados.",
    "No tags found" : "Nenhuma etiqueta encontrada",
    "Tags you have created will show up here." : "Asetiquetas que você criou aparecerão aqui.",
    "Failed to load tag" : "Falha ao carregar etiqueta",
    "Failed to load last used tags" : "Falha ao carregar as últimas etiquetas usadas",
    "Missing \"Content-Location\" header" : "Cabeçalho \"Conteúdo-Localização\" ausente",
    "A tag with the same name already exists" : "Uma etiqueta com o mesmo nome já existe",
    "Failed to load tags for file" : "Falha ao carregar etiquetas para arquivo",
    "Failed to set tag for file" : "Falha ao definir etiqueta para arquivo",
    "Failed to delete tag for file" : "Falha ao excluir etiqueta do arquivo",
    "This file has the tag {tag}" : "Este arquivo tem a tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este arquivo tem as etiquetas {firstTags} e {lastTag}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/pt_BR.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "A tag de sistema %1$s foi adicionado pelo sistema",
    "Added system tag {systemtag}" : "Adicionada a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Adicionada a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s adicionou a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} adicionou a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "A tag de sistema %1$s foi removida pelo sistema",
    "Removed system tag {systemtag}" : "Etiqueta de sistema excluída {systemtag}",
    "Removed system tag %1$s" : "Excluída a etiqueta da sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Você criou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Você criou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s criou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} criou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Você excluiu a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Você excluiu a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Você atualizou a etiqueta de sistema %2$s para %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Você atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atualizou a etiqueta de sistema %3$s para %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "A tag de sistema %2$s foi adicionado %1$s pelo sistema",
    "System tag {systemtag} was added to {file} by the system" : "A tag do sistema {systemtag} foi adicionada ao {file} pelo sistema",
    "You added system tag %2$s to %1$s" : "Você adicionou a etiqueta de sistema %2$s para %1$s",
    "You added system tag {systemtag} to {file}" : "Você adicionou a etiqueta de sistema {systemtag} para {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s adicionou a etiqueta de sistema %3$s para %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} adicionou a etiqueta de sistema {systemtag} para {file}",
    "System tag %2$s was removed from %1$s by the system" : "A tag de sistema %2$s foi removida de %1$s pelo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "A tag de sistema {systemtag} foi removida de {file} pelo sistema",
    "You removed system tag %2$s from %1$s" : "Você excluiu a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Você excluiu a etiqueta de sistema {systemtag} de {file} ",
    "%1$s removed system tag %3$s from %2$s" : "%1$s excluiu a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} excluiu a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrito)",
    "%s (invisible)" : "%s (invisível)",
    "<strong>System tags</strong> for a file have been modified" : "As <strong>etiquetas de sistema</strong> para um arquivo foram modificadas",
    "Files" : "Arquivos",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos os %s marcados …",
    "tagged %s" : "marcado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas. Ótimo para equipes. \n\t(Se você for um provedor com instalação multilocatária, é aconselhável desativar este aplicativo, pois as etiquetas são compartilhadas.)",
    "Public" : "Público",
    "Restricted" : "Restrito",
    "Invisible" : "Invisível",
    "Created tag" : "Etiqueta criada",
    "Failed to create tag" : "Falha ao criar etiqueta",
    "Updated tag" : "Etiqueta atualizada",
    "Failed to update tag" : "Falha ao atualizar a etiqueta",
    "Deleted tag" : "Etiqueta excluída",
    "Failed to delete tag" : "Falha ao excluir etiqueta",
    "Create or edit tags" : "Criar ou editar etiquetas",
    "Search for a tag to edit" : "Procure uma etiqueta para editar",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "No tags to select" : "Nenhuma etiqueta para selecionar",
    "Tag name" : "Nome da etiqueta",
    "Tag level" : "Nível de etiqueta",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Delete" : "Excluir",
    "Reset" : "Redefinir",
    "Loading …" : "Carregando …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} será definido e {tag2} será removido de 1 arquivo","{tag1} será definido e {tag2} será removido de {count} arquivos","{tag1} será definido e {tag2} será removido de {count} arquivos"],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} será definido em 1 arquivo","{tag} será definido em {count} arquivos","{tag} será definido em {count} arquivos"],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} será removido de 1 arquivo.","{tag} será removido de {count} arquivos.","{tag} será removido de {count} arquivos."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} serão definidos em 1 arquivo.","{tags} e {lastTag} serão definidos em {count} arquivos.","{tags} e {lastTag} serão definidos em {count} arquivos."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} e {lastTag} serão removidos de 1 arquivo.","{tags} e {lastTag} serão removidos de {count} arquivos.","{tags} e {lastTag} serão removidos de {count} arquivos."],
    "{displayName} (hidden)" : "{displayName} (escondida)",
    "{displayName} (restricted)" : "{displayName} (restrita)",
    "Only admins can create new tags" : "Somente os administradores podem criar novas etiquetas",
    "Failed to apply tags changes" : "Falha ao aplicar alterações de etiquetas",
    "File tags modification canceled" : "Modificação de etiquetas de arquivo cancelada",
    "Manage tags" : "Gerenciar etiquetas",
    "Applying tags changes…" : "Aplicando mudanças de etiquetas…",
    "Search or create tag" : "Pesquisar ou criar etiqueta",
    "Search tag" : "Pesquisar etiqueta",
    "Change tag color" : "Alterar cor da etiqueta",
    "Create new tag" : "Crie uma etiqueta nova",
    "Select or create tags to apply to all selected files" : "Selecione ou crie etiquetas para aplicar a todos os arquivos selecionados",
    "Select tags to apply to all selected files" : "Selecione etiquetas para aplicar a todos os arquivos selecionados",
    "Cancel" : "Cancelar",
    "Apply changes" : "Aplicar alterações",
    "Failed to load tags" : "Erro ao carregar rótulos",
    "Failed to load selected tags" : "Falha ao carregar as etiquetas selecionadas",
    "Failed to select tag" : "Falha ao selecionar etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "O administrador do sistema desativou a criação de etiquetas. Você só pode usar as que já existem.",
    "Loading collaborative tags …" : "Carregando etiquetas,s colaborativas…",
    "Search or create collaborative tags" : "Pesquise ou crie etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "Nenhuma etiqueta para selecionar, digite para criar uma nova etiqueta",
    "Unable to update setting" : "Não foi possível atualizar a configuração",
    "System tag creation is now restricted to administrators" : "A criação de etiquetas do sistema agora está restrita aos administradores",
    "System tag creation is now allowed for everybody" : "A criação de etiquetas do sistema agora está liberada para todos",
    "System tag management" : "Gerenciamento de etiquetas do sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Se ativado, somente os administradores poderão criar e editar etiquetas. As contas ainda podem atribuí-las e removê-las dos arquivos.",
    "Restrict tag creation and editing to administrators" : "Restringir a criação e a edição de atiquetas aos administradores",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
    "Assigned collaborative tags" : "Etiquetas colaborativas atribuídas",
    "Open in Files" : "Abrir em arquivos",
    "List of tags and their associated files and folders." : "Lista de etiquetas e seus arquivos e pastas associados.",
    "No tags found" : "Nenhuma etiqueta encontrada",
    "Tags you have created will show up here." : "Asetiquetas que você criou aparecerão aqui.",
    "Failed to load tag" : "Falha ao carregar etiqueta",
    "Failed to load last used tags" : "Falha ao carregar as últimas etiquetas usadas",
    "Missing \"Content-Location\" header" : "Cabeçalho \"Conteúdo-Localização\" ausente",
    "A tag with the same name already exists" : "Uma etiqueta com o mesmo nome já existe",
    "Failed to load tags for file" : "Falha ao carregar etiquetas para arquivo",
    "Failed to set tag for file" : "Falha ao definir etiqueta para arquivo",
    "Failed to delete tag for file" : "Falha ao excluir etiqueta do arquivo",
    "This file has the tag {tag}" : "Este arquivo tem a etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este arquivo tem as etiquetas {firstTags} e {lastTag}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
